% =============================================================================
%
% solve_NL_Monster
%
% CBP 01-01-21 Solver for ydotdot = -y * epsy^3
%
% =============================================================================

global eps

tstart = 0;
tend = input('Input end time');


% parameters ------------------------------------

eps = input('Input epsilon ');
a0 = 2.0;
xinit = [a0,0];

options = odeset('RelTol',1e-6,'AbsTol',1e-6,'InitialStep',tend/1e4,'MaxStep',tend/1e4);

[t,y] = ode45(@rhs_NL_Monster,[tstart,tend],xinit,options);


figure(1);
plot(y(:,1),y(:,2),'-');
hold on
plot(2*cos(t),-2*sin(t),'.');
axis('square');
xlabel('displacement');
ylabel('velocity');
str = sprintf("Phase plane for epsilon = %f\n",eps);
title(str);
hold off;

figure(2);
plot(t,y(:,1));
hold on;
omega = 1 - (3/8)*eps*a0*a0;
z = a0*cos(omega*t) + (1/32)*eps*a0*a0*a0*(cos(omega*t) - cos(3*omega*t));
%plot(t,z);
plot(t,2*cos(t),'-');
xlabel('time');
ylabel('displacement');
str = sprintf("x-t plot for epsilon = %f\n",eps);
title(str);
hold off;

printf("Period of linear system = %f\n",2*pi);
printf("Period of non-linear system (approx) = %f\n",2*pi/omega);


T = t(length(t))
N = length(y(:,2));

yy = fft(y(:,2));

f=[0:1/(T):(N-1)/(T)]';

figure(3);
plot(f,abs(yy));

